# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tendermint/state/types.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from tendermint.abci import types_pb2 as tendermint_dot_abci_dot_types__pb2
from tendermint.types import types_pb2 as tendermint_dot_types_dot_types__pb2
from tendermint.types import validator_pb2 as tendermint_dot_types_dot_validator__pb2
from tendermint.types import params_pb2 as tendermint_dot_types_dot_params__pb2
from tendermint.version import types_pb2 as tendermint_dot_version_dot_types__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tendermint/state/types.proto',
  package='tendermint.state',
  syntax='proto3',
  serialized_options=b'Z7github.com/tendermint/tendermint/proto/tendermint/state',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ctendermint/state/types.proto\x12\x10tendermint.state\x1a\x14gogoproto/gogo.proto\x1a\x1btendermint/abci/types.proto\x1a\x1ctendermint/types/types.proto\x1a tendermint/types/validator.proto\x1a\x1dtendermint/types/params.proto\x1a\x1etendermint/version/types.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb8\x01\n\rABCIResponses\x12\x37\n\x0b\x64\x65liver_txs\x18\x01 \x03(\x0b\x32\".tendermint.abci.ResponseDeliverTx\x12\x34\n\tend_block\x18\x02 \x01(\x0b\x32!.tendermint.abci.ResponseEndBlock\x12\x38\n\x0b\x62\x65gin_block\x18\x03 \x01(\x0b\x32#.tendermint.abci.ResponseBeginBlock\"d\n\x0eValidatorsInfo\x12\x35\n\rvalidator_set\x18\x01 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"u\n\x13\x43onsensusParamsInfo\x12\x41\n\x10\x63onsensus_params\x18\x01 \x01(\x0b\x32!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12\x1b\n\x13last_height_changed\x18\x02 \x01(\x03\"S\n\x07Version\x12\x36\n\tconsensus\x18\x01 \x01(\x0b\x32\x1d.tendermint.version.ConsensusB\x04\xc8\xde\x1f\x00\x12\x10\n\x08software\x18\x02 \x01(\t\"\xfd\x04\n\x05State\x12\x30\n\x07version\x18\x01 \x01(\x0b\x32\x19.tendermint.state.VersionB\x04\xc8\xde\x1f\x00\x12\x1d\n\x08\x63hain_id\x18\x02 \x01(\tB\x0b\xe2\xde\x1f\x07\x43hainID\x12\x16\n\x0einitial_height\x18\x0e \x01(\x03\x12\x19\n\x11last_block_height\x18\x03 \x01(\x03\x12\x45\n\rlast_block_id\x18\x04 \x01(\x0b\x32\x19.tendermint.types.BlockIDB\x13\xc8\xde\x1f\x00\xe2\xde\x1f\x0bLastBlockID\x12=\n\x0flast_block_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01\x12\x37\n\x0fnext_validators\x18\x06 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x32\n\nvalidators\x18\x07 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12\x37\n\x0flast_validators\x18\x08 \x01(\x0b\x32\x1e.tendermint.types.ValidatorSet\x12&\n\x1elast_height_validators_changed\x18\t \x01(\x03\x12\x41\n\x10\x63onsensus_params\x18\n \x01(\x0b\x32!.tendermint.types.ConsensusParamsB\x04\xc8\xde\x1f\x00\x12,\n$last_height_consensus_params_changed\x18\x0b \x01(\x03\x12\x19\n\x11last_results_hash\x18\x0c \x01(\x0c\x12\x10\n\x08\x61pp_hash\x18\r \x01(\x0c\x42\x39Z7github.com/tendermint/tendermint/proto/tendermint/stateb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,tendermint_dot_abci_dot_types__pb2.DESCRIPTOR,tendermint_dot_types_dot_types__pb2.DESCRIPTOR,tendermint_dot_types_dot_validator__pb2.DESCRIPTOR,tendermint_dot_types_dot_params__pb2.DESCRIPTOR,tendermint_dot_version_dot_types__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ABCIRESPONSES = _descriptor.Descriptor(
  name='ABCIResponses',
  full_name='tendermint.state.ABCIResponses',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deliver_txs', full_name='tendermint.state.ABCIResponses.deliver_txs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_block', full_name='tendermint.state.ABCIResponses.end_block', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='begin_block', full_name='tendermint.state.ABCIResponses.begin_block', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=262,
  serialized_end=446,
)


_VALIDATORSINFO = _descriptor.Descriptor(
  name='ValidatorsInfo',
  full_name='tendermint.state.ValidatorsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validator_set', full_name='tendermint.state.ValidatorsInfo.validator_set', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_height_changed', full_name='tendermint.state.ValidatorsInfo.last_height_changed', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=448,
  serialized_end=548,
)


_CONSENSUSPARAMSINFO = _descriptor.Descriptor(
  name='ConsensusParamsInfo',
  full_name='tendermint.state.ConsensusParamsInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consensus_params', full_name='tendermint.state.ConsensusParamsInfo.consensus_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_height_changed', full_name='tendermint.state.ConsensusParamsInfo.last_height_changed', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=667,
)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='tendermint.state.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='consensus', full_name='tendermint.state.Version.consensus', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='software', full_name='tendermint.state.Version.software', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=752,
)


_STATE = _descriptor.Descriptor(
  name='State',
  full_name='tendermint.state.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='tendermint.state.State.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='tendermint.state.State.chain_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\336\037\007ChainID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_height', full_name='tendermint.state.State.initial_height', index=2,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_block_height', full_name='tendermint.state.State.last_block_height', index=3,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_block_id', full_name='tendermint.state.State.last_block_id', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\342\336\037\013LastBlockID', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_block_time', full_name='tendermint.state.State.last_block_time', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\220\337\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_validators', full_name='tendermint.state.State.next_validators', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='validators', full_name='tendermint.state.State.validators', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_validators', full_name='tendermint.state.State.last_validators', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_height_validators_changed', full_name='tendermint.state.State.last_height_validators_changed', index=9,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='consensus_params', full_name='tendermint.state.State.consensus_params', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_height_consensus_params_changed', full_name='tendermint.state.State.last_height_consensus_params_changed', index=11,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_results_hash', full_name='tendermint.state.State.last_results_hash', index=12,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='app_hash', full_name='tendermint.state.State.app_hash', index=13,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=755,
  serialized_end=1392,
)

_ABCIRESPONSES.fields_by_name['deliver_txs'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSEDELIVERTX
_ABCIRESPONSES.fields_by_name['end_block'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSEENDBLOCK
_ABCIRESPONSES.fields_by_name['begin_block'].message_type = tendermint_dot_abci_dot_types__pb2._RESPONSEBEGINBLOCK
_VALIDATORSINFO.fields_by_name['validator_set'].message_type = tendermint_dot_types_dot_validator__pb2._VALIDATORSET
_CONSENSUSPARAMSINFO.fields_by_name['consensus_params'].message_type = tendermint_dot_types_dot_params__pb2._CONSENSUSPARAMS
_VERSION.fields_by_name['consensus'].message_type = tendermint_dot_version_dot_types__pb2._CONSENSUS
_STATE.fields_by_name['version'].message_type = _VERSION
_STATE.fields_by_name['last_block_id'].message_type = tendermint_dot_types_dot_types__pb2._BLOCKID
_STATE.fields_by_name['last_block_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATE.fields_by_name['next_validators'].message_type = tendermint_dot_types_dot_validator__pb2._VALIDATORSET
_STATE.fields_by_name['validators'].message_type = tendermint_dot_types_dot_validator__pb2._VALIDATORSET
_STATE.fields_by_name['last_validators'].message_type = tendermint_dot_types_dot_validator__pb2._VALIDATORSET
_STATE.fields_by_name['consensus_params'].message_type = tendermint_dot_types_dot_params__pb2._CONSENSUSPARAMS
DESCRIPTOR.message_types_by_name['ABCIResponses'] = _ABCIRESPONSES
DESCRIPTOR.message_types_by_name['ValidatorsInfo'] = _VALIDATORSINFO
DESCRIPTOR.message_types_by_name['ConsensusParamsInfo'] = _CONSENSUSPARAMSINFO
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ABCIResponses = _reflection.GeneratedProtocolMessageType('ABCIResponses', (_message.Message,), {
  'DESCRIPTOR' : _ABCIRESPONSES,
  '__module__' : 'tendermint.state.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.state.ABCIResponses)
  })
_sym_db.RegisterMessage(ABCIResponses)

ValidatorsInfo = _reflection.GeneratedProtocolMessageType('ValidatorsInfo', (_message.Message,), {
  'DESCRIPTOR' : _VALIDATORSINFO,
  '__module__' : 'tendermint.state.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.state.ValidatorsInfo)
  })
_sym_db.RegisterMessage(ValidatorsInfo)

ConsensusParamsInfo = _reflection.GeneratedProtocolMessageType('ConsensusParamsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CONSENSUSPARAMSINFO,
  '__module__' : 'tendermint.state.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.state.ConsensusParamsInfo)
  })
_sym_db.RegisterMessage(ConsensusParamsInfo)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'tendermint.state.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.state.Version)
  })
_sym_db.RegisterMessage(Version)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {
  'DESCRIPTOR' : _STATE,
  '__module__' : 'tendermint.state.types_pb2'
  # @@protoc_insertion_point(class_scope:tendermint.state.State)
  })
_sym_db.RegisterMessage(State)


DESCRIPTOR._options = None
_CONSENSUSPARAMSINFO.fields_by_name['consensus_params']._options = None
_VERSION.fields_by_name['consensus']._options = None
_STATE.fields_by_name['version']._options = None
_STATE.fields_by_name['chain_id']._options = None
_STATE.fields_by_name['last_block_id']._options = None
_STATE.fields_by_name['last_block_time']._options = None
_STATE.fields_by_name['consensus_params']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: exchange/injective_insurance_rpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='exchange/injective_insurance_rpc.proto',
  package='injective_insurance_rpc',
  syntax='proto3',
  serialized_options=b'Z\032/injective_insurance_rpcpb',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&exchange/injective_insurance_rpc.proto\x12\x17injective_insurance_rpc\"\x0e\n\x0c\x46undsRequest\"F\n\rFundsResponse\x12\x35\n\x05\x66unds\x18\x01 \x03(\x0b\x32&.injective_insurance_rpc.InsuranceFund\"\xcb\x02\n\rInsuranceFund\x12\x15\n\rmarket_ticker\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x15\n\rdeposit_denom\x18\x03 \x01(\t\x12\x18\n\x10pool_token_denom\x18\x04 \x01(\t\x12)\n!redemption_notice_period_duration\x18\x05 \x01(\x12\x12\x0f\n\x07\x62\x61lance\x18\x06 \x01(\t\x12\x13\n\x0btotal_share\x18\x07 \x01(\t\x12\x13\n\x0boracle_base\x18\x08 \x01(\t\x12\x14\n\x0coracle_quote\x18\t \x01(\t\x12\x13\n\x0boracle_type\x18\n \x01(\t\x12\x0e\n\x06\x65xpiry\x18\x0b \x01(\x12\x12>\n\x12\x64\x65posit_token_meta\x18\x0c \x01(\x0b\x32\".injective_insurance_rpc.TokenMeta\"n\n\tTokenMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\x0e\n\x06symbol\x18\x03 \x01(\t\x12\x0c\n\x04logo\x18\x04 \x01(\t\x12\x10\n\x08\x64\x65\x63imals\x18\x05 \x01(\x11\x12\x12\n\nupdated_at\x18\x06 \x01(\x12\"P\n\x12RedemptionsRequest\x12\x10\n\x08redeemer\x18\x01 \x01(\t\x12\x18\n\x10redemption_denom\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"`\n\x13RedemptionsResponse\x12I\n\x14redemption_schedules\x18\x01 \x03(\x0b\x32+.injective_insurance_rpc.RedemptionSchedule\"\x84\x02\n\x12RedemptionSchedule\x12\x15\n\rredemption_id\x18\x01 \x01(\x04\x12\x0e\n\x06status\x18\x02 \x01(\t\x12\x10\n\x08redeemer\x18\x03 \x01(\t\x12!\n\x19\x63laimable_redemption_time\x18\x04 \x01(\x12\x12\x19\n\x11redemption_amount\x18\x05 \x01(\t\x12\x18\n\x10redemption_denom\x18\x06 \x01(\t\x12\x14\n\x0crequested_at\x18\x07 \x01(\x12\x12\x18\n\x10\x64isbursed_amount\x18\x08 \x01(\t\x12\x17\n\x0f\x64isbursed_denom\x18\t \x01(\t\x12\x14\n\x0c\x64isbursed_at\x18\n \x01(\x12\x32\xd9\x01\n\x15InjectiveInsuranceRPC\x12V\n\x05\x46unds\x12%.injective_insurance_rpc.FundsRequest\x1a&.injective_insurance_rpc.FundsResponse\x12h\n\x0bRedemptions\x12+.injective_insurance_rpc.RedemptionsRequest\x1a,.injective_insurance_rpc.RedemptionsResponseB\x1cZ\x1a/injective_insurance_rpcpbb\x06proto3'
)




_FUNDSREQUEST = _descriptor.Descriptor(
  name='FundsRequest',
  full_name='injective_insurance_rpc.FundsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=81,
)


_FUNDSRESPONSE = _descriptor.Descriptor(
  name='FundsResponse',
  full_name='injective_insurance_rpc.FundsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='funds', full_name='injective_insurance_rpc.FundsResponse.funds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=153,
)


_INSURANCEFUND = _descriptor.Descriptor(
  name='InsuranceFund',
  full_name='injective_insurance_rpc.InsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_ticker', full_name='injective_insurance_rpc.InsuranceFund.market_ticker', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective_insurance_rpc.InsuranceFund.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_denom', full_name='injective_insurance_rpc.InsuranceFund.deposit_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_token_denom', full_name='injective_insurance_rpc.InsuranceFund.pool_token_denom', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_notice_period_duration', full_name='injective_insurance_rpc.InsuranceFund.redemption_notice_period_duration', index=4,
      number=5, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='injective_insurance_rpc.InsuranceFund.balance', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_share', full_name='injective_insurance_rpc.InsuranceFund.total_share', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective_insurance_rpc.InsuranceFund.oracle_base', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective_insurance_rpc.InsuranceFund.oracle_quote', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective_insurance_rpc.InsuranceFund.oracle_type', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective_insurance_rpc.InsuranceFund.expiry', index=10,
      number=11, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit_token_meta', full_name='injective_insurance_rpc.InsuranceFund.deposit_token_meta', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=156,
  serialized_end=487,
)


_TOKENMETA = _descriptor.Descriptor(
  name='TokenMeta',
  full_name='injective_insurance_rpc.TokenMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='injective_insurance_rpc.TokenMeta.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='injective_insurance_rpc.TokenMeta.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='injective_insurance_rpc.TokenMeta.symbol', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logo', full_name='injective_insurance_rpc.TokenMeta.logo', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decimals', full_name='injective_insurance_rpc.TokenMeta.decimals', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='injective_insurance_rpc.TokenMeta.updated_at', index=5,
      number=6, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=489,
  serialized_end=599,
)


_REDEMPTIONSREQUEST = _descriptor.Descriptor(
  name='RedemptionsRequest',
  full_name='injective_insurance_rpc.RedemptionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective_insurance_rpc.RedemptionsRequest.redeemer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_denom', full_name='injective_insurance_rpc.RedemptionsRequest.redemption_denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective_insurance_rpc.RedemptionsRequest.status', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=601,
  serialized_end=681,
)


_REDEMPTIONSRESPONSE = _descriptor.Descriptor(
  name='RedemptionsResponse',
  full_name='injective_insurance_rpc.RedemptionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redemption_schedules', full_name='injective_insurance_rpc.RedemptionsResponse.redemption_schedules', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=779,
)


_REDEMPTIONSCHEDULE = _descriptor.Descriptor(
  name='RedemptionSchedule',
  full_name='injective_insurance_rpc.RedemptionSchedule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='redemption_id', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='injective_insurance_rpc.RedemptionSchedule.status', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redeemer', full_name='injective_insurance_rpc.RedemptionSchedule.redeemer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claimable_redemption_time', full_name='injective_insurance_rpc.RedemptionSchedule.claimable_redemption_time', index=3,
      number=4, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_amount', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_amount', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redemption_denom', full_name='injective_insurance_rpc.RedemptionSchedule.redemption_denom', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='requested_at', full_name='injective_insurance_rpc.RedemptionSchedule.requested_at', index=6,
      number=7, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_amount', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_amount', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_denom', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_denom', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disbursed_at', full_name='injective_insurance_rpc.RedemptionSchedule.disbursed_at', index=9,
      number=10, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=1042,
)

_FUNDSRESPONSE.fields_by_name['funds'].message_type = _INSURANCEFUND
_INSURANCEFUND.fields_by_name['deposit_token_meta'].message_type = _TOKENMETA
_REDEMPTIONSRESPONSE.fields_by_name['redemption_schedules'].message_type = _REDEMPTIONSCHEDULE
DESCRIPTOR.message_types_by_name['FundsRequest'] = _FUNDSREQUEST
DESCRIPTOR.message_types_by_name['FundsResponse'] = _FUNDSRESPONSE
DESCRIPTOR.message_types_by_name['InsuranceFund'] = _INSURANCEFUND
DESCRIPTOR.message_types_by_name['TokenMeta'] = _TOKENMETA
DESCRIPTOR.message_types_by_name['RedemptionsRequest'] = _REDEMPTIONSREQUEST
DESCRIPTOR.message_types_by_name['RedemptionsResponse'] = _REDEMPTIONSRESPONSE
DESCRIPTOR.message_types_by_name['RedemptionSchedule'] = _REDEMPTIONSCHEDULE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FundsRequest = _reflection.GeneratedProtocolMessageType('FundsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FUNDSREQUEST,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.FundsRequest)
  })
_sym_db.RegisterMessage(FundsRequest)

FundsResponse = _reflection.GeneratedProtocolMessageType('FundsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FUNDSRESPONSE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.FundsResponse)
  })
_sym_db.RegisterMessage(FundsResponse)

InsuranceFund = _reflection.GeneratedProtocolMessageType('InsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _INSURANCEFUND,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.InsuranceFund)
  })
_sym_db.RegisterMessage(InsuranceFund)

TokenMeta = _reflection.GeneratedProtocolMessageType('TokenMeta', (_message.Message,), {
  'DESCRIPTOR' : _TOKENMETA,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.TokenMeta)
  })
_sym_db.RegisterMessage(TokenMeta)

RedemptionsRequest = _reflection.GeneratedProtocolMessageType('RedemptionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSREQUEST,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionsRequest)
  })
_sym_db.RegisterMessage(RedemptionsRequest)

RedemptionsResponse = _reflection.GeneratedProtocolMessageType('RedemptionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSRESPONSE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionsResponse)
  })
_sym_db.RegisterMessage(RedemptionsResponse)

RedemptionSchedule = _reflection.GeneratedProtocolMessageType('RedemptionSchedule', (_message.Message,), {
  'DESCRIPTOR' : _REDEMPTIONSCHEDULE,
  '__module__' : 'exchange.injective_insurance_rpc_pb2'
  # @@protoc_insertion_point(class_scope:injective_insurance_rpc.RedemptionSchedule)
  })
_sym_db.RegisterMessage(RedemptionSchedule)


DESCRIPTOR._options = None

_INJECTIVEINSURANCERPC = _descriptor.ServiceDescriptor(
  name='InjectiveInsuranceRPC',
  full_name='injective_insurance_rpc.InjectiveInsuranceRPC',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1045,
  serialized_end=1262,
  methods=[
  _descriptor.MethodDescriptor(
    name='Funds',
    full_name='injective_insurance_rpc.InjectiveInsuranceRPC.Funds',
    index=0,
    containing_service=None,
    input_type=_FUNDSREQUEST,
    output_type=_FUNDSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Redemptions',
    full_name='injective_insurance_rpc.InjectiveInsuranceRPC.Redemptions',
    index=1,
    containing_service=None,
    input_type=_REDEMPTIONSREQUEST,
    output_type=_REDEMPTIONSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INJECTIVEINSURANCERPC)

DESCRIPTOR.services_by_name['InjectiveInsuranceRPC'] = _INJECTIVEINSURANCERPC

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmwasm/wasm/v1/ibc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmwasm/wasm/v1/ibc.proto',
  package='cosmwasm.wasm.v1',
  syntax='proto3',
  serialized_options=b'Z&github.com/CosmWasm/wasmd/x/wasm/types\310\341\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63osmwasm/wasm/v1/ibc.proto\x12\x10\x63osmwasm.wasm.v1\x1a\x14gogoproto/gogo.proto\"\xb2\x01\n\nMsgIBCSend\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"\x12\x31\n\x0etimeout_height\x18\x04 \x01(\x04\x42\x19\xf2\xde\x1f\x15yaml:\"timeout_height\"\x12\x37\n\x11timeout_timestamp\x18\x05 \x01(\x04\x42\x1c\xf2\xde\x1f\x18yaml:\"timeout_timestamp\"\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\x0c\"@\n\x12MsgIBCCloseChannel\x12*\n\x07\x63hannel\x18\x02 \x01(\tB\x19\xf2\xde\x1f\x15yaml:\"source_channel\"B,Z&github.com/CosmWasm/wasmd/x/wasm/types\xc8\xe1\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_MSGIBCSEND = _descriptor.Descriptor(
  name='MsgIBCSend',
  full_name='cosmwasm.wasm.v1.MsgIBCSend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='cosmwasm.wasm.v1.MsgIBCSend.channel', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"source_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_height', full_name='cosmwasm.wasm.v1.MsgIBCSend.timeout_height', index=1,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"timeout_height\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_timestamp', full_name='cosmwasm.wasm.v1.MsgIBCSend.timeout_timestamp', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\030yaml:\"timeout_timestamp\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='cosmwasm.wasm.v1.MsgIBCSend.data', index=3,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=249,
)


_MSGIBCCLOSECHANNEL = _descriptor.Descriptor(
  name='MsgIBCCloseChannel',
  full_name='cosmwasm.wasm.v1.MsgIBCCloseChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='cosmwasm.wasm.v1.MsgIBCCloseChannel.channel', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\025yaml:\"source_channel\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=315,
)

DESCRIPTOR.message_types_by_name['MsgIBCSend'] = _MSGIBCSEND
DESCRIPTOR.message_types_by_name['MsgIBCCloseChannel'] = _MSGIBCCLOSECHANNEL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgIBCSend = _reflection.GeneratedProtocolMessageType('MsgIBCSend', (_message.Message,), {
  'DESCRIPTOR' : _MSGIBCSEND,
  '__module__' : 'cosmwasm.wasm.v1.ibc_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.MsgIBCSend)
  })
_sym_db.RegisterMessage(MsgIBCSend)

MsgIBCCloseChannel = _reflection.GeneratedProtocolMessageType('MsgIBCCloseChannel', (_message.Message,), {
  'DESCRIPTOR' : _MSGIBCCLOSECHANNEL,
  '__module__' : 'cosmwasm.wasm.v1.ibc_pb2'
  # @@protoc_insertion_point(class_scope:cosmwasm.wasm.v1.MsgIBCCloseChannel)
  })
_sym_db.RegisterMessage(MsgIBCCloseChannel)


DESCRIPTOR._options = None
_MSGIBCSEND.fields_by_name['channel']._options = None
_MSGIBCSEND.fields_by_name['timeout_height']._options = None
_MSGIBCSEND.fields_by_name['timeout_timestamp']._options = None
_MSGIBCCLOSECHANNEL.fields_by_name['channel']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/base/query/v1beta1/pagination.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/base/query/v1beta1/pagination.proto',
  package='cosmos.base.query.v1beta1',
  syntax='proto3',
  serialized_options=b'Z(github.com/cosmos/cosmos-sdk/types/query',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n*cosmos/base/query/v1beta1/pagination.proto\x12\x19\x63osmos.base.query.v1beta1\"_\n\x0bPageRequest\x12\x0b\n\x03key\x18\x01 \x01(\x0c\x12\x0e\n\x06offset\x18\x02 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x13\n\x0b\x63ount_total\x18\x04 \x01(\x08\x12\x0f\n\x07reverse\x18\x05 \x01(\x08\"/\n\x0cPageResponse\x12\x10\n\x08next_key\x18\x01 \x01(\x0c\x12\r\n\x05total\x18\x02 \x01(\x04\x42*Z(github.com/cosmos/cosmos-sdk/types/queryb\x06proto3'
)




_PAGEREQUEST = _descriptor.Descriptor(
  name='PageRequest',
  full_name='cosmos.base.query.v1beta1.PageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.base.query.v1beta1.PageRequest.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='cosmos.base.query.v1beta1.PageRequest.offset', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='cosmos.base.query.v1beta1.PageRequest.limit', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count_total', full_name='cosmos.base.query.v1beta1.PageRequest.count_total', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='cosmos.base.query.v1beta1.PageRequest.reverse', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=168,
)


_PAGERESPONSE = _descriptor.Descriptor(
  name='PageResponse',
  full_name='cosmos.base.query.v1beta1.PageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next_key', full_name='cosmos.base.query.v1beta1.PageResponse.next_key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='cosmos.base.query.v1beta1.PageResponse.total', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=217,
)

DESCRIPTOR.message_types_by_name['PageRequest'] = _PAGEREQUEST
DESCRIPTOR.message_types_by_name['PageResponse'] = _PAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PageRequest = _reflection.GeneratedProtocolMessageType('PageRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAGEREQUEST,
  '__module__' : 'cosmos.base.query.v1beta1.pagination_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.query.v1beta1.PageRequest)
  })
_sym_db.RegisterMessage(PageRequest)

PageResponse = _reflection.GeneratedProtocolMessageType('PageResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAGERESPONSE,
  '__module__' : 'cosmos.base.query.v1beta1.pagination_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.query.v1beta1.PageResponse)
  })
_sym_db.RegisterMessage(PageResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from injective.peggy.v1 import types_pb2 as injective_dot_peggy_dot_v1_dot_types__pb2
from injective.peggy.v1 import msgs_pb2 as injective_dot_peggy_dot_v1_dot_msgs__pb2
from injective.peggy.v1 import batch_pb2 as injective_dot_peggy_dot_v1_dot_batch__pb2
from injective.peggy.v1 import attestation_pb2 as injective_dot_peggy_dot_v1_dot_attestation__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/genesis.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n injective/peggy/v1/genesis.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto\x1a\x1einjective/peggy/v1/types.proto\x1a\x1dinjective/peggy/v1/msgs.proto\x1a\x1einjective/peggy/v1/batch.proto\x1a$injective/peggy/v1/attestation.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\xb7\x07\n\x06Params\x12\x10\n\x08peggy_id\x18\x01 \x01(\t\x12\x1c\n\x14\x63ontract_source_hash\x18\x02 \x01(\t\x12\x1f\n\x17\x62ridge_ethereum_address\x18\x03 \x01(\t\x12\x17\n\x0f\x62ridge_chain_id\x18\x04 \x01(\x04\x12\x1d\n\x15signed_valsets_window\x18\x05 \x01(\x04\x12\x1d\n\x15signed_batches_window\x18\x06 \x01(\x04\x12\x1c\n\x14signed_claims_window\x18\x07 \x01(\x04\x12\x1c\n\x14target_batch_timeout\x18\x08 \x01(\x04\x12\x1a\n\x12\x61verage_block_time\x18\t \x01(\x04\x12#\n\x1b\x61verage_ethereum_block_time\x18\n \x01(\x04\x12M\n\x15slash_fraction_valset\x18\x0b \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14slash_fraction_batch\x18\x0c \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12L\n\x14slash_fraction_claim\x18\r \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12X\n slash_fraction_conflicting_claim\x18\x0e \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12&\n\x1eunbond_slashing_valsets_window\x18\x0f \x01(\x04\x12X\n slash_fraction_bad_eth_signature\x18\x10 \x01(\x0c\x42.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x19\n\x11\x63osmos_coin_denom\x18\x11 \x01(\t\x12\"\n\x1a\x63osmos_coin_erc20_contract\x18\x12 \x01(\t\x12\x1e\n\x16\x63laim_slashing_enabled\x18\x13 \x01(\x08\x12$\n\x1c\x62ridge_contract_start_height\x18\x14 \x01(\x04\x12\x36\n\rvalset_reward\x18\x15 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x04\x80\xdc \x00\"\x80\x06\n\x0cGenesisState\x12*\n\x06params\x18\x01 \x01(\x0b\x32\x1a.injective.peggy.v1.Params\x12\x1b\n\x13last_observed_nonce\x18\x02 \x01(\x04\x12+\n\x07valsets\x18\x03 \x03(\x0b\x32\x1a.injective.peggy.v1.Valset\x12=\n\x0fvalset_confirms\x18\x04 \x03(\x0b\x32$.injective.peggy.v1.MsgValsetConfirm\x12\x34\n\x07\x62\x61tches\x18\x05 \x03(\x0b\x32#.injective.peggy.v1.OutgoingTxBatch\x12;\n\x0e\x62\x61tch_confirms\x18\x06 \x03(\x0b\x32#.injective.peggy.v1.MsgConfirmBatch\x12\x35\n\x0c\x61ttestations\x18\x07 \x03(\x0b\x32\x1f.injective.peggy.v1.Attestation\x12O\n\x16orchestrator_addresses\x18\x08 \x03(\x0b\x32/.injective.peggy.v1.MsgSetOrchestratorAddresses\x12\x39\n\x0f\x65rc20_to_denoms\x18\t \x03(\x0b\x32 .injective.peggy.v1.ERC20ToDenom\x12\x43\n\x13unbatched_transfers\x18\n \x03(\x0b\x32&.injective.peggy.v1.OutgoingTransferTx\x12%\n\x1dlast_observed_ethereum_height\x18\x0b \x01(\x04\x12\x1e\n\x16last_outgoing_batch_id\x18\x0c \x01(\x04\x12\x1d\n\x15last_outgoing_pool_id\x18\r \x01(\x04\x12>\n\x14last_observed_valset\x18\x0e \x01(\x0b\x32\x1a.injective.peggy.v1.ValsetB\x04\xc8\xde\x1f\x00\x12\x1a\n\x12\x65thereum_blacklist\x18\x0f \x03(\tBMZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_types__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_msgs__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_batch__pb2.DESCRIPTOR,injective_dot_peggy_dot_v1_dot_attestation__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,])




_PARAMS = _descriptor.Descriptor(
  name='Params',
  full_name='injective.peggy.v1.Params',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='peggy_id', full_name='injective.peggy.v1.Params.peggy_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contract_source_hash', full_name='injective.peggy.v1.Params.contract_source_hash', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_ethereum_address', full_name='injective.peggy.v1.Params.bridge_ethereum_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_chain_id', full_name='injective.peggy.v1.Params.bridge_chain_id', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_valsets_window', full_name='injective.peggy.v1.Params.signed_valsets_window', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_batches_window', full_name='injective.peggy.v1.Params.signed_batches_window', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signed_claims_window', full_name='injective.peggy.v1.Params.signed_claims_window', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_batch_timeout', full_name='injective.peggy.v1.Params.target_batch_timeout', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_block_time', full_name='injective.peggy.v1.Params.average_block_time', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='average_ethereum_block_time', full_name='injective.peggy.v1.Params.average_ethereum_block_time', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slash_fraction_valset', full_name='injective.peggy.v1.Params.slash_fraction_valset', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slash_fraction_batch', full_name='injective.peggy.v1.Params.slash_fraction_batch', index=11,
      number=12, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slash_fraction_claim', full_name='injective.peggy.v1.Params.slash_fraction_claim', index=12,
      number=13, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slash_fraction_conflicting_claim', full_name='injective.peggy.v1.Params.slash_fraction_conflicting_claim', index=13,
      number=14, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unbond_slashing_valsets_window', full_name='injective.peggy.v1.Params.unbond_slashing_valsets_window', index=14,
      number=15, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slash_fraction_bad_eth_signature', full_name='injective.peggy.v1.Params.slash_fraction_bad_eth_signature', index=15,
      number=16, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_coin_denom', full_name='injective.peggy.v1.Params.cosmos_coin_denom', index=16,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cosmos_coin_erc20_contract', full_name='injective.peggy.v1.Params.cosmos_coin_erc20_contract', index=17,
      number=18, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='claim_slashing_enabled', full_name='injective.peggy.v1.Params.claim_slashing_enabled', index=18,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridge_contract_start_height', full_name='injective.peggy.v1.Params.bridge_contract_start_height', index=19,
      number=20, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_reward', full_name='injective.peggy.v1.Params.valset_reward', index=20,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\200\334 \000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=244,
  serialized_end=1195,
)


_GENESISSTATE = _descriptor.Descriptor(
  name='GenesisState',
  full_name='injective.peggy.v1.GenesisState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.peggy.v1.GenesisState.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_observed_nonce', full_name='injective.peggy.v1.GenesisState.last_observed_nonce', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valsets', full_name='injective.peggy.v1.GenesisState.valsets', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='valset_confirms', full_name='injective.peggy.v1.GenesisState.valset_confirms', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batches', full_name='injective.peggy.v1.GenesisState.batches', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='batch_confirms', full_name='injective.peggy.v1.GenesisState.batch_confirms', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attestations', full_name='injective.peggy.v1.GenesisState.attestations', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='orchestrator_addresses', full_name='injective.peggy.v1.GenesisState.orchestrator_addresses', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='erc20_to_denoms', full_name='injective.peggy.v1.GenesisState.erc20_to_denoms', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unbatched_transfers', full_name='injective.peggy.v1.GenesisState.unbatched_transfers', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_observed_ethereum_height', full_name='injective.peggy.v1.GenesisState.last_observed_ethereum_height', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_outgoing_batch_id', full_name='injective.peggy.v1.GenesisState.last_outgoing_batch_id', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_outgoing_pool_id', full_name='injective.peggy.v1.GenesisState.last_outgoing_pool_id', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_observed_valset', full_name='injective.peggy.v1.GenesisState.last_observed_valset', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ethereum_blacklist', full_name='injective.peggy.v1.GenesisState.ethereum_blacklist', index=14,
      number=15, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1966,
)

_PARAMS.fields_by_name['valset_reward'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_GENESISSTATE.fields_by_name['params'].message_type = _PARAMS
_GENESISSTATE.fields_by_name['valsets'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
_GENESISSTATE.fields_by_name['valset_confirms'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGVALSETCONFIRM
_GENESISSTATE.fields_by_name['batches'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTXBATCH
_GENESISSTATE.fields_by_name['batch_confirms'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGCONFIRMBATCH
_GENESISSTATE.fields_by_name['attestations'].message_type = injective_dot_peggy_dot_v1_dot_attestation__pb2._ATTESTATION
_GENESISSTATE.fields_by_name['orchestrator_addresses'].message_type = injective_dot_peggy_dot_v1_dot_msgs__pb2._MSGSETORCHESTRATORADDRESSES
_GENESISSTATE.fields_by_name['erc20_to_denoms'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._ERC20TODENOM
_GENESISSTATE.fields_by_name['unbatched_transfers'].message_type = injective_dot_peggy_dot_v1_dot_batch__pb2._OUTGOINGTRANSFERTX
_GENESISSTATE.fields_by_name['last_observed_valset'].message_type = injective_dot_peggy_dot_v1_dot_types__pb2._VALSET
DESCRIPTOR.message_types_by_name['Params'] = _PARAMS
DESCRIPTOR.message_types_by_name['GenesisState'] = _GENESISSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Params = _reflection.GeneratedProtocolMessageType('Params', (_message.Message,), {
  'DESCRIPTOR' : _PARAMS,
  '__module__' : 'injective.peggy.v1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.Params)
  })
_sym_db.RegisterMessage(Params)

GenesisState = _reflection.GeneratedProtocolMessageType('GenesisState', (_message.Message,), {
  'DESCRIPTOR' : _GENESISSTATE,
  '__module__' : 'injective.peggy.v1.genesis_pb2'
  # @@protoc_insertion_point(class_scope:injective.peggy.v1.GenesisState)
  })
_sym_db.RegisterMessage(GenesisState)


DESCRIPTOR._options = None
_PARAMS.fields_by_name['slash_fraction_valset']._options = None
_PARAMS.fields_by_name['slash_fraction_batch']._options = None
_PARAMS.fields_by_name['slash_fraction_claim']._options = None
_PARAMS.fields_by_name['slash_fraction_conflicting_claim']._options = None
_PARAMS.fields_by_name['slash_fraction_bad_eth_signature']._options = None
_PARAMS.fields_by_name['valset_reward']._options = None
_PARAMS._options = None
_GENESISSTATE.fields_by_name['last_observed_valset']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/insurance/v1beta1/tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/insurance/v1beta1/tx.proto',
  package='injective.insurance.v1beta1',
  syntax='proto3',
  serialized_options=b'ZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$injective/insurance/v1beta1/tx.proto\x12\x1binjective.insurance.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a%injective/oracle/v1beta1/oracle.proto\"\x87\x02\n\x16MsgCreateInsuranceFund\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x0e\n\x06ticker\x18\x02 \x01(\t\x12\x13\n\x0bquote_denom\x18\x03 \x01(\t\x12\x13\n\x0boracle_base\x18\x04 \x01(\t\x12\x14\n\x0coracle_quote\x18\x05 \x01(\t\x12\x39\n\x0boracle_type\x18\x06 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleType\x12\x0e\n\x06\x65xpiry\x18\x07 \x01(\x03\x12\x38\n\x0finitial_deposit\x18\x08 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\" \n\x1eMsgCreateInsuranceFundResponse\"n\n\rMsgUnderwrite\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\x30\n\x07\x64\x65posit\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x17\n\x15MsgUnderwriteResponse\"t\n\x14MsgRequestRedemption\x12\x0e\n\x06sender\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12/\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x19.cosmos.base.v1beta1.CoinB\x04\xc8\xde\x1f\x00:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\"\x1e\n\x1cMsgRequestRedemptionResponse2\x81\x03\n\x03Msg\x12\x87\x01\n\x13\x43reateInsuranceFund\x12\x33.injective.insurance.v1beta1.MsgCreateInsuranceFund\x1a;.injective.insurance.v1beta1.MsgCreateInsuranceFundResponse\x12l\n\nUnderwrite\x12*.injective.insurance.v1beta1.MsgUnderwrite\x1a\x32.injective.insurance.v1beta1.MsgUnderwriteResponse\x12\x81\x01\n\x11RequestRedemption\x12\x31.injective.insurance.v1beta1.MsgRequestRedemption\x1a\x39.injective.insurance.v1beta1.MsgRequestRedemptionResponseBQZOgithub.com/InjectiveLabs/injective-core/injective-chain/modules/insurance/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,cosmos_dot_base_dot_v1beta1_dot_coin__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,])




_MSGCREATEINSURANCEFUND = _descriptor.Descriptor(
  name='MsgCreateInsuranceFund',
  full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ticker', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.ticker', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_denom', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.quote_denom', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_base', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_base', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_quote', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_quote', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_type', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.oracle_type', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiry', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.expiry', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_deposit', full_name='injective.insurance.v1beta1.MsgCreateInsuranceFund.initial_deposit', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=426,
)


_MSGCREATEINSURANCEFUNDRESPONSE = _descriptor.Descriptor(
  name='MsgCreateInsuranceFundResponse',
  full_name='injective.insurance.v1beta1.MsgCreateInsuranceFundResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=428,
  serialized_end=460,
)


_MSGUNDERWRITE = _descriptor.Descriptor(
  name='MsgUnderwrite',
  full_name='injective.insurance.v1beta1.MsgUnderwrite',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgUnderwrite.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.MsgUnderwrite.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deposit', full_name='injective.insurance.v1beta1.MsgUnderwrite.deposit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=572,
)


_MSGUNDERWRITERESPONSE = _descriptor.Descriptor(
  name='MsgUnderwriteResponse',
  full_name='injective.insurance.v1beta1.MsgUnderwriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=597,
)


_MSGREQUESTREDEMPTION = _descriptor.Descriptor(
  name='MsgRequestRedemption',
  full_name='injective.insurance.v1beta1.MsgRequestRedemption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sender', full_name='injective.insurance.v1beta1.MsgRequestRedemption.sender', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.insurance.v1beta1.MsgRequestRedemption.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='injective.insurance.v1beta1.MsgRequestRedemption.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=715,
)


_MSGREQUESTREDEMPTIONRESPONSE = _descriptor.Descriptor(
  name='MsgRequestRedemptionResponse',
  full_name='injective.insurance.v1beta1.MsgRequestRedemptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=717,
  serialized_end=747,
)

_MSGCREATEINSURANCEFUND.fields_by_name['oracle_type'].enum_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._ORACLETYPE
_MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGUNDERWRITE.fields_by_name['deposit'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
_MSGREQUESTREDEMPTION.fields_by_name['amount'].message_type = cosmos_dot_base_dot_v1beta1_dot_coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgCreateInsuranceFund'] = _MSGCREATEINSURANCEFUND
DESCRIPTOR.message_types_by_name['MsgCreateInsuranceFundResponse'] = _MSGCREATEINSURANCEFUNDRESPONSE
DESCRIPTOR.message_types_by_name['MsgUnderwrite'] = _MSGUNDERWRITE
DESCRIPTOR.message_types_by_name['MsgUnderwriteResponse'] = _MSGUNDERWRITERESPONSE
DESCRIPTOR.message_types_by_name['MsgRequestRedemption'] = _MSGREQUESTREDEMPTION
DESCRIPTOR.message_types_by_name['MsgRequestRedemptionResponse'] = _MSGREQUESTREDEMPTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgCreateInsuranceFund = _reflection.GeneratedProtocolMessageType('MsgCreateInsuranceFund', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINSURANCEFUND,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgCreateInsuranceFund)
  })
_sym_db.RegisterMessage(MsgCreateInsuranceFund)

MsgCreateInsuranceFundResponse = _reflection.GeneratedProtocolMessageType('MsgCreateInsuranceFundResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGCREATEINSURANCEFUNDRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgCreateInsuranceFundResponse)
  })
_sym_db.RegisterMessage(MsgCreateInsuranceFundResponse)

MsgUnderwrite = _reflection.GeneratedProtocolMessageType('MsgUnderwrite', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNDERWRITE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgUnderwrite)
  })
_sym_db.RegisterMessage(MsgUnderwrite)

MsgUnderwriteResponse = _reflection.GeneratedProtocolMessageType('MsgUnderwriteResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGUNDERWRITERESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgUnderwriteResponse)
  })
_sym_db.RegisterMessage(MsgUnderwriteResponse)

MsgRequestRedemption = _reflection.GeneratedProtocolMessageType('MsgRequestRedemption', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTREDEMPTION,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgRequestRedemption)
  })
_sym_db.RegisterMessage(MsgRequestRedemption)

MsgRequestRedemptionResponse = _reflection.GeneratedProtocolMessageType('MsgRequestRedemptionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGREQUESTREDEMPTIONRESPONSE,
  '__module__' : 'injective.insurance.v1beta1.tx_pb2'
  # @@protoc_insertion_point(class_scope:injective.insurance.v1beta1.MsgRequestRedemptionResponse)
  })
_sym_db.RegisterMessage(MsgRequestRedemptionResponse)


DESCRIPTOR._options = None
_MSGCREATEINSURANCEFUND.fields_by_name['initial_deposit']._options = None
_MSGCREATEINSURANCEFUND._options = None
_MSGUNDERWRITE.fields_by_name['deposit']._options = None
_MSGUNDERWRITE._options = None
_MSGREQUESTREDEMPTION.fields_by_name['amount']._options = None
_MSGREQUESTREDEMPTION._options = None

_MSG = _descriptor.ServiceDescriptor(
  name='Msg',
  full_name='injective.insurance.v1beta1.Msg',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=750,
  serialized_end=1135,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateInsuranceFund',
    full_name='injective.insurance.v1beta1.Msg.CreateInsuranceFund',
    index=0,
    containing_service=None,
    input_type=_MSGCREATEINSURANCEFUND,
    output_type=_MSGCREATEINSURANCEFUNDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Underwrite',
    full_name='injective.insurance.v1beta1.Msg.Underwrite',
    index=1,
    containing_service=None,
    input_type=_MSGUNDERWRITE,
    output_type=_MSGUNDERWRITERESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RequestRedemption',
    full_name='injective.insurance.v1beta1.Msg.RequestRedemption',
    index=2,
    containing_service=None,
    input_type=_MSGREQUESTREDEMPTION,
    output_type=_MSGREQUESTREDEMPTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MSG)

DESCRIPTOR.services_by_name['Msg'] = _MSG

# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from exchange import injective_meta_rpc_pb2 as exchange_dot_injective__meta__rpc__pb2


class InjectiveMetaRPCStub(object):
    """InjectiveMetaRPC is a special API subset to get info about server.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Ping = channel.unary_unary(
                '/injective_meta_rpc.InjectiveMetaRPC/Ping',
                request_serializer=exchange_dot_injective__meta__rpc__pb2.PingRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__meta__rpc__pb2.PingResponse.FromString,
                )
        self.Version = channel.unary_unary(
                '/injective_meta_rpc.InjectiveMetaRPC/Version',
                request_serializer=exchange_dot_injective__meta__rpc__pb2.VersionRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__meta__rpc__pb2.VersionResponse.FromString,
                )
        self.Info = channel.unary_unary(
                '/injective_meta_rpc.InjectiveMetaRPC/Info',
                request_serializer=exchange_dot_injective__meta__rpc__pb2.InfoRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__meta__rpc__pb2.InfoResponse.FromString,
                )
        self.StreamKeepalive = channel.unary_stream(
                '/injective_meta_rpc.InjectiveMetaRPC/StreamKeepalive',
                request_serializer=exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveRequest.SerializeToString,
                response_deserializer=exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveResponse.FromString,
                )


class InjectiveMetaRPCServicer(object):
    """InjectiveMetaRPC is a special API subset to get info about server.
    """

    def Ping(self, request, context):
        """Endpoint for checking server health.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Version(self, request, context):
        """Returns injective-exchange version.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Info(self, request, context):
        """Gets connection info
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamKeepalive(self, request, context):
        """Stream keepalive, if server exits, a shutdown event will be sent over this
        channel.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InjectiveMetaRPCServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Ping': grpc.unary_unary_rpc_method_handler(
                    servicer.Ping,
                    request_deserializer=exchange_dot_injective__meta__rpc__pb2.PingRequest.FromString,
                    response_serializer=exchange_dot_injective__meta__rpc__pb2.PingResponse.SerializeToString,
            ),
            'Version': grpc.unary_unary_rpc_method_handler(
                    servicer.Version,
                    request_deserializer=exchange_dot_injective__meta__rpc__pb2.VersionRequest.FromString,
                    response_serializer=exchange_dot_injective__meta__rpc__pb2.VersionResponse.SerializeToString,
            ),
            'Info': grpc.unary_unary_rpc_method_handler(
                    servicer.Info,
                    request_deserializer=exchange_dot_injective__meta__rpc__pb2.InfoRequest.FromString,
                    response_serializer=exchange_dot_injective__meta__rpc__pb2.InfoResponse.SerializeToString,
            ),
            'StreamKeepalive': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamKeepalive,
                    request_deserializer=exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveRequest.FromString,
                    response_serializer=exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective_meta_rpc.InjectiveMetaRPC', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InjectiveMetaRPC(object):
    """InjectiveMetaRPC is a special API subset to get info about server.
    """

    @staticmethod
    def Ping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_meta_rpc.InjectiveMetaRPC/Ping',
            exchange_dot_injective__meta__rpc__pb2.PingRequest.SerializeToString,
            exchange_dot_injective__meta__rpc__pb2.PingResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Version(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_meta_rpc.InjectiveMetaRPC/Version',
            exchange_dot_injective__meta__rpc__pb2.VersionRequest.SerializeToString,
            exchange_dot_injective__meta__rpc__pb2.VersionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Info(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/injective_meta_rpc.InjectiveMetaRPC/Info',
            exchange_dot_injective__meta__rpc__pb2.InfoRequest.SerializeToString,
            exchange_dot_injective__meta__rpc__pb2.InfoResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamKeepalive(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/injective_meta_rpc.InjectiveMetaRPC/StreamKeepalive',
            exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveRequest.SerializeToString,
            exchange_dot_injective__meta__rpc__pb2.StreamKeepaliveResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/crypto/secp256r1/keys.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='cosmos/crypto/secp256r1/keys.proto',
  package='cosmos.crypto.secp256r1',
  syntax='proto3',
  serialized_options=b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\310\343\036\001\330\341\036\000\310\341\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"cosmos/crypto/secp256r1/keys.proto\x12\x17\x63osmos.crypto.secp256r1\x1a\x14gogoproto/gogo.proto\"\"\n\x06PubKey\x12\x18\n\x03key\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saPK\"&\n\x07PrivKey\x12\x1b\n\x06secret\x18\x01 \x01(\x0c\x42\x0b\xda\xde\x1f\x07\x65\x63\x64saSKB@Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256r1\xc8\xe3\x1e\x01\xd8\xe1\x1e\x00\xc8\xe1\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])




_PUBKEY = _descriptor.Descriptor(
  name='PubKey',
  full_name='cosmos.crypto.secp256r1.PubKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.crypto.secp256r1.PubKey.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\007ecdsaPK', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=85,
  serialized_end=119,
)


_PRIVKEY = _descriptor.Descriptor(
  name='PrivKey',
  full_name='cosmos.crypto.secp256r1.PrivKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='secret', full_name='cosmos.crypto.secp256r1.PrivKey.secret', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\007ecdsaSK', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=159,
)

DESCRIPTOR.message_types_by_name['PubKey'] = _PUBKEY
DESCRIPTOR.message_types_by_name['PrivKey'] = _PRIVKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PubKey = _reflection.GeneratedProtocolMessageType('PubKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEY,
  '__module__' : 'cosmos.crypto.secp256r1.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.secp256r1.PubKey)
  })
_sym_db.RegisterMessage(PubKey)

PrivKey = _reflection.GeneratedProtocolMessageType('PrivKey', (_message.Message,), {
  'DESCRIPTOR' : _PRIVKEY,
  '__module__' : 'cosmos.crypto.secp256r1.keys_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.secp256r1.PrivKey)
  })
_sym_db.RegisterMessage(PrivKey)


DESCRIPTOR._options = None
_PUBKEY.fields_by_name['key']._options = None
_PRIVKEY.fields_by_name['secret']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ibc/core/port/v1/query.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ibc.core.channel.v1 import channel_pb2 as ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='ibc/core/port/v1/query.proto',
  package='ibc.core.port.v1',
  syntax='proto3',
  serialized_options=b'Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cibc/core/port/v1/query.proto\x12\x10ibc.core.port.v1\x1a!ibc/core/channel/v1/channel.proto\"\xc1\x01\n\x16QueryAppVersionRequest\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x15\n\rconnection_id\x18\x02 \x01(\t\x12,\n\x08ordering\x18\x03 \x01(\x0e\x32\x1a.ibc.core.channel.v1.Order\x12\x37\n\x0c\x63ounterparty\x18\x04 \x01(\x0b\x32!.ibc.core.channel.v1.Counterparty\x12\x18\n\x10proposed_version\x18\x05 \x01(\t\";\n\x17QueryAppVersionResponse\x12\x0f\n\x07port_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2l\n\x05Query\x12\x63\n\nAppVersion\x12(.ibc.core.port.v1.QueryAppVersionRequest\x1a).ibc.core.port.v1.QueryAppVersionResponse\"\x00\x42\x38Z6github.com/cosmos/ibc-go/v2/modules/core/05-port/typesb\x06proto3'
  ,
  dependencies=[ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2.DESCRIPTOR,])




_QUERYAPPVERSIONREQUEST = _descriptor.Descriptor(
  name='QueryAppVersionRequest',
  full_name='ibc.core.port.v1.QueryAppVersionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.port.v1.QueryAppVersionRequest.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='connection_id', full_name='ibc.core.port.v1.QueryAppVersionRequest.connection_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordering', full_name='ibc.core.port.v1.QueryAppVersionRequest.ordering', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counterparty', full_name='ibc.core.port.v1.QueryAppVersionRequest.counterparty', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposed_version', full_name='ibc.core.port.v1.QueryAppVersionRequest.proposed_version', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=279,
)


_QUERYAPPVERSIONRESPONSE = _descriptor.Descriptor(
  name='QueryAppVersionResponse',
  full_name='ibc.core.port.v1.QueryAppVersionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='port_id', full_name='ibc.core.port.v1.QueryAppVersionResponse.port_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='ibc.core.port.v1.QueryAppVersionResponse.version', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=340,
)

_QUERYAPPVERSIONREQUEST.fields_by_name['ordering'].enum_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._ORDER
_QUERYAPPVERSIONREQUEST.fields_by_name['counterparty'].message_type = ibc_dot_core_dot_channel_dot_v1_dot_channel__pb2._COUNTERPARTY
DESCRIPTOR.message_types_by_name['QueryAppVersionRequest'] = _QUERYAPPVERSIONREQUEST
DESCRIPTOR.message_types_by_name['QueryAppVersionResponse'] = _QUERYAPPVERSIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QueryAppVersionRequest = _reflection.GeneratedProtocolMessageType('QueryAppVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAPPVERSIONREQUEST,
  '__module__' : 'ibc.core.port.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.port.v1.QueryAppVersionRequest)
  })
_sym_db.RegisterMessage(QueryAppVersionRequest)

QueryAppVersionResponse = _reflection.GeneratedProtocolMessageType('QueryAppVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYAPPVERSIONRESPONSE,
  '__module__' : 'ibc.core.port.v1.query_pb2'
  # @@protoc_insertion_point(class_scope:ibc.core.port.v1.QueryAppVersionResponse)
  })
_sym_db.RegisterMessage(QueryAppVersionResponse)


DESCRIPTOR._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='ibc.core.port.v1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=342,
  serialized_end=450,
  methods=[
  _descriptor.MethodDescriptor(
    name='AppVersion',
    full_name='ibc.core.port.v1.Query.AppVersion',
    index=0,
    containing_service=None,
    input_type=_QUERYAPPVERSIONREQUEST,
    output_type=_QUERYAPPVERSIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)



from web3 import Web3
import logging

from .wallet import Address

logging.basicConfig(format='%(levelname)s:%(message)s', level=logging.INFO)

class Peggo:
    def __init__(self, network: str):
        self.network = network
    def sendToInjective(self, ethereum_endpoint: str, private_key: str, token_contract: str, receiver: str, amount: int,
                     maxFeePerGas: int, maxPriorityFeePerGas: int, peggo_abi: str, data: str, decimals=18):
        if self.network == 'testnet':
            peggy_proxy_address = "0xd2C6753F6B1783EF0a3857275e16e79D91b539a3"
        elif self.network == 'mainnet':
            peggy_proxy_address = "0xF955C57f9EA9Dc8781965FEaE0b6A2acE2BAD6f3"
        elif self.network == 'devnet':
            peggy_proxy_address = "0x4F38F75606d046819638f909b66B112aF1095e8d"
        else:
            logging.info("Network is not supported")
        web3 = Web3(Web3.HTTPProvider(ethereum_endpoint))
        contract = web3.eth.contract(address=peggy_proxy_address, abi=peggo_abi)

        token_contract_address = web3.toChecksumAddress(token_contract)

        receiver_address = Address.from_acc_bech32(receiver)
        receiver_ethereum_address = Address.get_ethereum_address(receiver_address)
        receiver_address_checksum = web3.toChecksumAddress(receiver_ethereum_address)
        receiver_slice = receiver_address_checksum[2:]
        receiver_padded_address = '0x' + receiver_slice.zfill(64)

        destination = web3.toBytes(hexstr=receiver_padded_address)

        sender_ethereum_address = web3.eth.account.privateKeyToAccount(private_key).address
        sender_address_checksum = web3.toChecksumAddress(sender_ethereum_address)
        nonce = web3.eth.get_transaction_count(sender_address_checksum)

        amount_to_send = int(amount * pow(10, decimals))

        gas = contract.functions.sendToInjective(
            token_contract_address,
            destination,
            amount_to_send,
            data
        ).estimateGas({'from': sender_address_checksum})

        transaction_body = {
            'nonce': nonce,
            'gas': gas,
            'maxFeePerGas': web3.toWei(maxFeePerGas, 'gwei'),
            'maxPriorityFeePerGas': web3.toWei(maxPriorityFeePerGas, 'gwei'),
        }

        tx = contract.functions.sendToInjective(
            token_contract_address,
            destination,
            amount_to_send,
            data
        ).buildTransaction(transaction_body)

        signed_tx = web3.eth.account.signTransaction(tx, private_key=private_key)

        try:
            tx_hash = web3.eth.send_raw_transaction(signed_tx.rawTransaction)
            logging.info("Transferred {} {} from {} to {}".format(amount, token_contract, sender_ethereum_address, receiver))
            logging.info("Transaction hash:".format(web3.toHex(tx_hash)))
        except Exception as e:
            logging.info("Transaction failed".format(e))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/peggy/v1/ethereum_signer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/peggy/v1/ethereum_signer.proto',
  package='injective.peggy.v1',
  syntax='proto3',
  serialized_options=b'ZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(injective/peggy/v1/ethereum_signer.proto\x12\x12injective.peggy.v1\x1a\x14gogoproto/gogo.proto*\x91\x01\n\x08SignType\x12\x15\n\x11SIGN_TYPE_UNKNOWN\x10\x00\x12\x32\n.SIGN_TYPE_ORCHESTRATOR_SIGNED_MULTI_SIG_UPDATE\x10\x01\x12\x30\n,SIGN_TYPE_ORCHESTRATOR_SIGNED_WITHDRAW_BATCH\x10\x02\x1a\x08\x88\xa3\x1e\x00\xa8\xa4\x1e\x00\x42MZKgithub.com/InjectiveLabs/injective-core/injective-chain/modules/peggy/typesb\x06proto3'
  ,
  dependencies=[gogoproto_dot_gogo__pb2.DESCRIPTOR,])

_SIGNTYPE = _descriptor.EnumDescriptor(
  name='SignType',
  full_name='injective.peggy.v1.SignType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SIGN_TYPE_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGN_TYPE_ORCHESTRATOR_SIGNED_MULTI_SIG_UPDATE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SIGN_TYPE_ORCHESTRATOR_SIGNED_WITHDRAW_BATCH', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\210\243\036\000\250\244\036\000',
  serialized_start=87,
  serialized_end=232,
)
_sym_db.RegisterEnumDescriptor(_SIGNTYPE)

SignType = enum_type_wrapper.EnumTypeWrapper(_SIGNTYPE)
SIGN_TYPE_UNKNOWN = 0
SIGN_TYPE_ORCHESTRATOR_SIGNED_MULTI_SIG_UPDATE = 1
SIGN_TYPE_ORCHESTRATOR_SIGNED_WITHDRAW_BATCH = 2


DESCRIPTOR.enum_types_by_name['SignType'] = _SIGNTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)


DESCRIPTOR._options = None
_SIGNTYPE._options = None
# @@protoc_insertion_point(module_scope)
